Learn R Programming

uncertainUCDP (version 0.7.6)

ucdpged: UCDP Georeferenced Event Dataset (GED) sample

Description

A sample of the UCDP Georeferenced Event Dataset (GED) from the 2023 data release. The data contains information about the date, location, and type of conflict events. The data is a sample of the full dataset, which can be downloaded from the UCDP website <https://ucdp.uu.se/downloads/>.

Usage

ucdpged

Arguments

Format

a tibble with 1000 rows and 49 columns