data(ucdpged)
# Calculate the mean for an arbitrary UCDP event
mean_uncertainUCDP(fatalities = 100, tov = 'sb')
# Calculate the mean for the first event in the UCDP GED sample
mean_uncertainUCDP(ucdpged$best[1], tov = ucdpged$type_of_violence[1])
# Calculate the median for an arbitrary UCDP event
median_uncertainUCDP(fatalities = 100, tov = 'sb')
# Calculate the median for the first event in the UCDP GED sample
median_uncertainUCDP(ucdpged$best[1], tov = ucdpged$type_of_violence[1])
# Calculate the 90th percentile for an arbitrary UCDP event
quantile_uncertainUCDP(probs = 0.9, fatalities = 100, tov = 'sb')
# Calculate the 90th percentile for the first event in the UCDP GED sample
quantile_uncertainUCDP(ucdpged$best[1], 0.9, tov = ucdpged$type_of_violence[1])
Run the code above in your browser using DataLab